==> helm-annotations-4.0.0-sources.jar: io/dekorate/helm/config/AddIfStatement.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.sundr.builder.annotations.Buildable;

 /**
  * Generated
  */
  @Buildable(refs = {@io.sundr.builder.annotations.BuildableReference(value = io.dekorate.project.Project.class),@io.sundr.builder.annotations.BuildableReference(value = io.dekorate.project.BuildInfo.class)} ,builderPackage = "io.fabric8.kubernetes.api.builder")
  public class AddIfStatement{
  public AddIfStatement() {
  }
  public AddIfStatement(String property,String onResourceKind,String onResourceName,Boolean withDefaultValue,String description) {
    this.property = property;
    this.onResourceKind = onResourceKind;
    this.onResourceName = onResourceName;
    this.withDefaultValue = withDefaultValue;
    this.description = description;
  }
  private String property;
  private String onResourceKind;
  private String onResourceName;
  private Boolean withDefaultValue;
  private String description;
  public String getProperty() {
    return this.property;
  }
  public String getOnResourceKind() {
    return this.onResourceKind;
  }
  public String getOnResourceName() {
    return this.onResourceName;
  }
  public Boolean getWithDefaultValue() {
    return this.withDefaultValue;
  }
  public boolean isWithDefaultValue() {
    return this.withDefaultValue != null &&  this.withDefaultValue;
  }
  public String getDescription() {
    return this.description;
  }
  public static AddIfStatementBuilder newBuilder() {
    return new AddIfStatementBuilder();
  }
  public static AddIfStatementBuilder newBuilderFromDefaults() {
    return new AddIfStatementBuilder().withWithDefaultValue(true);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddIfStatement that = (AddIfStatement) o;
    if (!java.util.Objects.equals(property, that.property)) return false;

    if (!java.util.Objects.equals(onResourceKind, that.onResourceKind)) return false;

    if (!java.util.Objects.equals(onResourceName, that.onResourceName)) return false;

    if (!java.util.Objects.equals(withDefaultValue, that.withDefaultValue)) return false;

    if (!java.util.Objects.equals(description, that.description)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(property,  onResourceKind,  onResourceName,  withDefaultValue,  description,  super.hashCode());
  }
  
}

==> helm-annotations-4.0.3-sources.jar: io/dekorate/helm/config/AddIfStatement.java <==
package io.dekorate.helm.config;

import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.sundr.builder.annotations.Buildable;

/**
 * Generated
 */
@Buildable(refs = {@io.sundr.builder.annotations.BuildableReference(io.dekorate.project.Project.class),@io.sundr.builder.annotations.BuildableReference(io.dekorate.project.BuildInfo.class)} ,builderPackage = "io.fabric8.kubernetes.api.builder")
public class AddIfStatement{
  public AddIfStatement() {
  }
  
  public AddIfStatement(String property,String onResourceKind,String onResourceName,Boolean withDefaultValue,String description) {
    this.property = property;
    this.onResourceKind = onResourceKind;
    this.onResourceName = onResourceName;
    this.withDefaultValue = withDefaultValue;
    this.description = description;
  }
  private String property;
  private String onResourceKind;
  private String onResourceName;
  private Boolean withDefaultValue;
  private String description;
  
  public String getProperty() {
    return this.property;
  }
  
  public String getOnResourceKind() {
    return this.onResourceKind;
  }
  
  public String getOnResourceName() {
    return this.onResourceName;
  }
  
  public Boolean getWithDefaultValue() {
    return this.withDefaultValue;
  }
  
  public boolean isWithDefaultValue() {
    return this.withDefaultValue != null &&  this.withDefaultValue;
  }
  
  public String getDescription() {
    return this.description;
  }
  
  public static AddIfStatementBuilder newBuilder() {
    return new AddIfStatementBuilder();
  }
  
  public static AddIfStatementBuilder newBuilderFromDefaults() {
    return new AddIfStatementBuilder().withWithDefaultValue(true);
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddIfStatement that = (AddIfStatement) o;
    if (!java.util.Objects.equals(property, that.property)) return false;
    if (!java.util.Objects.equals(onResourceKind, that.onResourceKind)) return false;
    if (!java.util.Objects.equals(onResourceName, that.onResourceName)) return false;
    if (!java.util.Objects.equals(withDefaultValue, that.withDefaultValue)) return false;
    if (!java.util.Objects.equals(description, that.description)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(property,  onResourceKind,  onResourceName,  withDefaultValue,  description,  super.hashCode());
  }
  

}
